@@ -1,5 +1,5 @@
 # -*- coding: utf8 -*-
-# Copyright (c) 2017-2021 THL A29 Limited, a Tencent company. All Rights Reserved.
+# Copyright (c) 2017-2025 Tencent. All Rights Reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -27,7 +27,7 @@ class PrivatednsClient(AbstractClient):
 
 
     def AddSpecifyPrivateZoneVpc(self, request):
-        """追加与私有域关联的VPC
+        r"""追加与私有域关联的VPC
 
         :param request: Request instance for AddSpecifyPrivateZoneVpc.
         :type request: :class:`tencentcloud.privatedns.v20201028.models.AddSpecifyPrivateZoneVpcRequest`
@@ -49,8 +49,77 @@ class PrivatednsClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def CreateExtendEndpoint(self, request):
+        r"""创建终端节点
+
+        :param request: Request instance for CreateExtendEndpoint.
+        :type request: :class:`tencentcloud.privatedns.v20201028.models.CreateExtendEndpointRequest`
+        :rtype: :class:`tencentcloud.privatedns.v20201028.models.CreateExtendEndpointResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("CreateExtendEndpoint", params, headers=headers)
+            response = json.loads(body)
+            model = models.CreateExtendEndpointResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
+    def CreateForwardRule(self, request):
+        r"""创建自定义转发规则
+
+        :param request: Request instance for CreateForwardRule.
+        :type request: :class:`tencentcloud.privatedns.v20201028.models.CreateForwardRuleRequest`
+        :rtype: :class:`tencentcloud.privatedns.v20201028.models.CreateForwardRuleResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("CreateForwardRule", params, headers=headers)
+            response = json.loads(body)
+            model = models.CreateForwardRuleResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
+    def CreateInboundEndpoint(self, request):
+        r"""删除入站终端节点
+
+        :param request: Request instance for CreateInboundEndpoint.
+        :type request: :class:`tencentcloud.privatedns.v20201028.models.CreateInboundEndpointRequest`
+        :rtype: :class:`tencentcloud.privatedns.v20201028.models.CreateInboundEndpointResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("CreateInboundEndpoint", params, headers=headers)
+            response = json.loads(body)
+            model = models.CreateInboundEndpointResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def CreatePrivateDNSAccount(self, request):
-        """创建私有域解析账号
+        r"""跨账号关联VPC时绑定其他账号
 
         :param request: Request instance for CreatePrivateDNSAccount.
         :type request: :class:`tencentcloud.privatedns.v20201028.models.CreatePrivateDNSAccountRequest`
@@ -73,7 +142,7 @@ class PrivatednsClient(AbstractClient):
 
 
     def CreatePrivateZone(self, request):
-        """创建私有域
+        r"""创建私有域
 
         :param request: Request instance for CreatePrivateZone.
         :type request: :class:`tencentcloud.privatedns.v20201028.models.CreatePrivateZoneRequest`
@@ -96,7 +165,7 @@ class PrivatednsClient(AbstractClient):
 
 
     def CreatePrivateZoneRecord(self, request):
-        """添加私有域解析记录
+        r"""添加私有域解析记录
 
         :param request: Request instance for CreatePrivateZoneRecord.
         :type request: :class:`tencentcloud.privatedns.v20201028.models.CreatePrivateZoneRecordRequest`
@@ -119,7 +188,7 @@ class PrivatednsClient(AbstractClient):
 
 
     def DeleteEndPoint(self, request):
-        """删除终端节点
+        r"""删除终端节点
 
         :param request: Request instance for DeleteEndPoint.
         :type request: :class:`tencentcloud.privatedns.v20201028.models.DeleteEndPointRequest`
@@ -141,8 +210,54 @@ class PrivatednsClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def DeleteForwardRule(self, request):
+        r"""删除转发规则并停止转发
+
+        :param request: Request instance for DeleteForwardRule.
+        :type request: :class:`tencentcloud.privatedns.v20201028.models.DeleteForwardRuleRequest`
+        :rtype: :class:`tencentcloud.privatedns.v20201028.models.DeleteForwardRuleResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DeleteForwardRule", params, headers=headers)
+            response = json.loads(body)
+            model = models.DeleteForwardRuleResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
+    def DeleteInboundEndpoint(self, request):
+        r"""删除入站终端节点
+
+        :param request: Request instance for DeleteInboundEndpoint.
+        :type request: :class:`tencentcloud.privatedns.v20201028.models.DeleteInboundEndpointRequest`
+        :rtype: :class:`tencentcloud.privatedns.v20201028.models.DeleteInboundEndpointResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DeleteInboundEndpoint", params, headers=headers)
+            response = json.loads(body)
+            model = models.DeleteInboundEndpointResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def DeletePrivateDNSAccount(self, request):
-        """删除私有域解析账号
+        r"""删除私有域解析账号
 
         :param request: Request instance for DeletePrivateDNSAccount.
         :type request: :class:`tencentcloud.privatedns.v20201028.models.DeletePrivateDNSAccountRequest`
@@ -165,7 +280,7 @@ class PrivatednsClient(AbstractClient):
 
 
     def DeletePrivateZone(self, request):
-        """删除私有域并停止解析
+        r"""删除私有域并停止解析
 
         :param request: Request instance for DeletePrivateZone.
         :type request: :class:`tencentcloud.privatedns.v20201028.models.DeletePrivateZoneRequest`
@@ -188,7 +303,7 @@ class PrivatednsClient(AbstractClient):
 
 
     def DeletePrivateZoneRecord(self, request):
-        """删除私有域解析记录
+        r"""删除私有域解析记录
 
         :param request: Request instance for DeletePrivateZoneRecord.
         :type request: :class:`tencentcloud.privatedns.v20201028.models.DeletePrivateZoneRecordRequest`
@@ -211,7 +326,7 @@ class PrivatednsClient(AbstractClient):
 
 
     def DeleteSpecifyPrivateZoneVpc(self, request):
-        """删除与私有域关联的VPC
+        r"""删除与私有域关联的VPC
 
         :param request: Request instance for DeleteSpecifyPrivateZoneVpc.
         :type request: :class:`tencentcloud.privatedns.v20201028.models.DeleteSpecifyPrivateZoneVpcRequest`
@@ -234,7 +349,7 @@ class PrivatednsClient(AbstractClient):
 
 
     def DescribeAccountVpcList(self, request):
-        """获取私有域解析账号的VPC列表
+        r"""获取私有域解析账号的VPC列表
 
         :param request: Request instance for DescribeAccountVpcList.
         :type request: :class:`tencentcloud.privatedns.v20201028.models.DescribeAccountVpcListRequest`
@@ -257,7 +372,7 @@ class PrivatednsClient(AbstractClient):
 
 
     def DescribeAuditLog(self, request):
-        """获取操作日志列表
+        r"""获取操作日志列表
 
         :param request: Request instance for DescribeAuditLog.
         :type request: :class:`tencentcloud.privatedns.v20201028.models.DescribeAuditLogRequest`
@@ -280,7 +395,7 @@ class PrivatednsClient(AbstractClient):
 
 
     def DescribeDashboard(self, request):
-        """获取私有域解析概览
+        r"""获取私有域解析概览
 
         :param request: Request instance for DescribeDashboard.
         :type request: :class:`tencentcloud.privatedns.v20201028.models.DescribeDashboardRequest`
@@ -302,8 +417,77 @@ class PrivatednsClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def DescribeExtendEndpointList(self, request):
+        r"""获取终端节点列表
+
+        :param request: Request instance for DescribeExtendEndpointList.
+        :type request: :class:`tencentcloud.privatedns.v20201028.models.DescribeExtendEndpointListRequest`
+        :rtype: :class:`tencentcloud.privatedns.v20201028.models.DescribeExtendEndpointListResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DescribeExtendEndpointList", params, headers=headers)
+            response = json.loads(body)
+            model = models.DescribeExtendEndpointListResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
+    def DescribeForwardRuleList(self, request):
+        r"""查询转发规则列表
+
+        :param request: Request instance for DescribeForwardRuleList.
+        :type request: :class:`tencentcloud.privatedns.v20201028.models.DescribeForwardRuleListRequest`
+        :rtype: :class:`tencentcloud.privatedns.v20201028.models.DescribeForwardRuleListResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DescribeForwardRuleList", params, headers=headers)
+            response = json.loads(body)
+            model = models.DescribeForwardRuleListResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
+    def DescribeInboundEndpointList(self, request):
+        r"""获取入站终端节点列表
+
+        :param request: Request instance for DescribeInboundEndpointList.
+        :type request: :class:`tencentcloud.privatedns.v20201028.models.DescribeInboundEndpointListRequest`
+        :rtype: :class:`tencentcloud.privatedns.v20201028.models.DescribeInboundEndpointListResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DescribeInboundEndpointList", params, headers=headers)
+            response = json.loads(body)
+            model = models.DescribeInboundEndpointListResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def DescribePrivateDNSAccountList(self, request):
-        """获取私有域解析账号列表
+        r"""获取私有域解析账号列表
 
         :param request: Request instance for DescribePrivateDNSAccountList.
         :type request: :class:`tencentcloud.privatedns.v20201028.models.DescribePrivateDNSAccountListRequest`
@@ -326,7 +510,7 @@ class PrivatednsClient(AbstractClient):
 
 
     def DescribePrivateZone(self, request):
-        """获取私有域信息
+        r"""获取私有域信息
 
         :param request: Request instance for DescribePrivateZone.
         :type request: :class:`tencentcloud.privatedns.v20201028.models.DescribePrivateZoneRequest`
@@ -349,7 +533,7 @@ class PrivatednsClient(AbstractClient):
 
 
     def DescribePrivateZoneList(self, request):
-        """获取私有域列表
+        r"""获取私有域列表
 
         :param request: Request instance for DescribePrivateZoneList.
         :type request: :class:`tencentcloud.privatedns.v20201028.models.DescribePrivateZoneListRequest`
@@ -372,7 +556,7 @@ class PrivatednsClient(AbstractClient):
 
 
     def DescribePrivateZoneRecordList(self, request):
-        """获取私有域记录列表
+        r"""获取私有域记录列表
 
         :param request: Request instance for DescribePrivateZoneRecordList.
         :type request: :class:`tencentcloud.privatedns.v20201028.models.DescribePrivateZoneRecordListRequest`
@@ -395,7 +579,7 @@ class PrivatednsClient(AbstractClient):
 
 
     def DescribePrivateZoneService(self, request):
-        """查询私有域解析开通状态
+        r"""查询私有域解析开通状态
 
         :param request: Request instance for DescribePrivateZoneService.
         :type request: :class:`tencentcloud.privatedns.v20201028.models.DescribePrivateZoneServiceRequest`
@@ -418,7 +602,7 @@ class PrivatednsClient(AbstractClient):
 
 
     def DescribeQuotaUsage(self, request):
-        """查询额度使用情况
+        r"""查询额度使用情况
 
         :param request: Request instance for DescribeQuotaUsage.
         :type request: :class:`tencentcloud.privatedns.v20201028.models.DescribeQuotaUsageRequest`
@@ -440,8 +624,31 @@ class PrivatednsClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def DescribeRecord(self, request):
+        r"""获取私有域记录
+
+        :param request: Request instance for DescribeRecord.
+        :type request: :class:`tencentcloud.privatedns.v20201028.models.DescribeRecordRequest`
+        :rtype: :class:`tencentcloud.privatedns.v20201028.models.DescribeRecordResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DescribeRecord", params, headers=headers)
+            response = json.loads(body)
+            model = models.DescribeRecordResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def DescribeRequestData(self, request):
-        """获取私有域解析请求量
+        r"""获取私有域解析请求量
 
         :param request: Request instance for DescribeRequestData.
         :type request: :class:`tencentcloud.privatedns.v20201028.models.DescribeRequestDataRequest`
@@ -463,8 +670,54 @@ class PrivatednsClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def ModifyForwardRule(self, request):
+        r"""修改转发规则
+
+        :param request: Request instance for ModifyForwardRule.
+        :type request: :class:`tencentcloud.privatedns.v20201028.models.ModifyForwardRuleRequest`
+        :rtype: :class:`tencentcloud.privatedns.v20201028.models.ModifyForwardRuleResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("ModifyForwardRule", params, headers=headers)
+            response = json.loads(body)
+            model = models.ModifyForwardRuleResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
+    def ModifyInboundEndpoint(self, request):
+        r"""删除入站终端节点
+
+        :param request: Request instance for ModifyInboundEndpoint.
+        :type request: :class:`tencentcloud.privatedns.v20201028.models.ModifyInboundEndpointRequest`
+        :rtype: :class:`tencentcloud.privatedns.v20201028.models.ModifyInboundEndpointResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("ModifyInboundEndpoint", params, headers=headers)
+            response = json.loads(body)
+            model = models.ModifyInboundEndpointResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def ModifyPrivateZone(self, request):
-        """修改私有域信息
+        r"""修改私有域信息
 
         :param request: Request instance for ModifyPrivateZone.
         :type request: :class:`tencentcloud.privatedns.v20201028.models.ModifyPrivateZoneRequest`
@@ -487,7 +740,7 @@ class PrivatednsClient(AbstractClient):
 
 
     def ModifyPrivateZoneRecord(self, request):
-        """修改私有域解析记录
+        r"""修改私有域解析记录
 
         :param request: Request instance for ModifyPrivateZoneRecord.
         :type request: :class:`tencentcloud.privatedns.v20201028.models.ModifyPrivateZoneRecordRequest`
@@ -510,7 +763,7 @@ class PrivatednsClient(AbstractClient):
 
 
     def ModifyPrivateZoneVpc(self, request):
-        """修改私有域关联的VPC
+        r"""修改私有域关联的VPC
 
         :param request: Request instance for ModifyPrivateZoneVpc.
         :type request: :class:`tencentcloud.privatedns.v20201028.models.ModifyPrivateZoneVpcRequest`
@@ -533,7 +786,7 @@ class PrivatednsClient(AbstractClient):
 
 
     def ModifyRecordsStatus(self, request):
-        """修改解析记录状态
+        r"""修改解析记录状态
 
         :param request: Request instance for ModifyRecordsStatus.
         :type request: :class:`tencentcloud.privatedns.v20201028.models.ModifyRecordsStatusRequest`
@@ -555,8 +808,31 @@ class PrivatednsClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def QueryAsyncBindVpcStatus(self, request):
+        r"""查询异步绑定vpc操作状态
+
+        :param request: Request instance for QueryAsyncBindVpcStatus.
+        :type request: :class:`tencentcloud.privatedns.v20201028.models.QueryAsyncBindVpcStatusRequest`
+        :rtype: :class:`tencentcloud.privatedns.v20201028.models.QueryAsyncBindVpcStatusResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("QueryAsyncBindVpcStatus", params, headers=headers)
+            response = json.loads(body)
+            model = models.QueryAsyncBindVpcStatusResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def SubscribePrivateZoneService(self, request):
-        """开通私有域解析
+        r"""开通私有域解析
 
         :param request: Request instance for SubscribePrivateZoneService.
         :type request: :class:`tencentcloud.privatedns.v20201028.models.SubscribePrivateZoneServiceRequest`
